fnss.topologies.parsers.parse_inet — FNSS 0.7.0 documentation

# fnss.topologies.parsers.parse_inet

`parse_inet`(path)

  Parse a topology from an output file generated by the Inet topology generator

  Parameters: | path : str The path to the Inet output file
  Returns: | topology : Topology

  Notes

  Each node of the returned topology object is labeled with latitude and longitude attributes. These attributes are not expressed in degrees but in Kilometers.